
# Auto Activenv

Python package to automatically activate virtual environments when installed
Compatible with Python2 and Python3.5+

## Disclaimers
- This package is NOT compatible with Windows
- This package (as of right now) will only work if you name your virtual
environments `venv`

## Usage
- `pip install auto-activenv`
- `activenv --help` for options
- Once installed, it is safe to remove the CLI `pip uninstall auto-activenv`

## TODO's
- Change name of virtualenvs with option or use regex to determine virtualenvs
- Install detection

